==> skill-core-0.0.3-sources.jar: com/ptteng/sca/common/skill/client/ArticleTaskRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.ArticleTaskRelation;
import com.ptteng.common.skill.service.ArticleTaskRelationService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class ArticleTaskRelationSCAClient implements ArticleTaskRelationService {

    private ArticleTaskRelationService articleTaskRelationService;

	public ArticleTaskRelationService getArticleTaskRelationService() {
		return articleTaskRelationService;
	}
	
	
	public void setArticleTaskRelationService(ArticleTaskRelationService articleTaskRelationService) {
		this.articleTaskRelationService =articleTaskRelationService;
	}
	
	
			   
		@Override
		public Long insert(ArticleTaskRelation articleTaskRelation)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.insert(articleTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<ArticleTaskRelation> insertList(List<ArticleTaskRelation> articleTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.insertList(articleTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(ArticleTaskRelation articleTaskRelation)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.update(articleTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<ArticleTaskRelation> articleTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.updateList(articleTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public ArticleTaskRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<ArticleTaskRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getArticleTaskRelationIdsByDid(Long did,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getArticleTaskRelationIdsByDid(did,start,limit);
	
	
	}

	@Override
	public List<Long> getTidsByDid(Long did, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.getTidsByDid(did,start,limit);
	}

	@Override
	public List<Long> getDidsByTid(Long tid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.getDidsByTid(tid, start, limit);
	}

	@Override
	public Integer countDidsByTid(Long tid) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.countDidsByTid(tid);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getArticleTaskRelationIdsByTid(Long tid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getArticleTaskRelationIdsByTid(tid,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getArticleTaskRelationIdByDidAndTid(Long did,Long tid)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getArticleTaskRelationIdByDidAndTid(did,tid);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countArticleTaskRelationIdsByDid(Long did)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.countArticleTaskRelationIdsByDid(did);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countArticleTaskRelationIdsByTid(Long tid)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.countArticleTaskRelationIdsByTid(tid);
	
	
	}
	
		
	
		@Override
	public List<Long> getArticleTaskRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.getArticleTaskRelationIds(start, limit);
	}

	@Override
	public Integer countArticleTaskRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.countArticleTaskRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   articleTaskRelationService.deleteList(clz, ids);
		
	}


 
}

==> skill-core-30.0.0-sources.jar: com/ptteng/sca/common/skill/client/ArticleTaskRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.ArticleTaskRelation;
import com.ptteng.common.skill.service.ArticleTaskRelationService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class ArticleTaskRelationSCAClient implements ArticleTaskRelationService {

    private ArticleTaskRelationService articleTaskRelationService;

	public ArticleTaskRelationService getArticleTaskRelationService() {
		return articleTaskRelationService;
	}
	
	
	public void setArticleTaskRelationService(ArticleTaskRelationService articleTaskRelationService) {
		this.articleTaskRelationService =articleTaskRelationService;
	}
	
	
			   
		@Override
		public Long insert(ArticleTaskRelation articleTaskRelation)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.insert(articleTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<ArticleTaskRelation> insertList(List<ArticleTaskRelation> articleTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.insertList(articleTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(ArticleTaskRelation articleTaskRelation)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.update(articleTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<ArticleTaskRelation> articleTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.updateList(articleTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public ArticleTaskRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<ArticleTaskRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getArticleTaskRelationIdsByDid(Long did,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getArticleTaskRelationIdsByDid(did,start,limit);
	
	
	}

	@Override
	public List<Long> getTidsByDid(Long did, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.getTidsByDid(did,start,limit);
	}

	@Override
	public List<Long> getDidsByTid(Long tid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.getDidsByTid(tid, start, limit);
	}

	@Override
	public Integer countDidsByTid(Long tid) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.countDidsByTid(tid);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getArticleTaskRelationIdsByTid(Long tid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getArticleTaskRelationIdsByTid(tid,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getArticleTaskRelationIdByDidAndTid(Long did,Long tid)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.getArticleTaskRelationIdByDidAndTid(did,tid);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countArticleTaskRelationIdsByDid(Long did)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.countArticleTaskRelationIdsByDid(did);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countArticleTaskRelationIdsByTid(Long tid)throws ServiceException, ServiceDaoException{
		
		return articleTaskRelationService.countArticleTaskRelationIdsByTid(tid);
	
	
	}
	
		
	
		@Override
	public List<Long> getArticleTaskRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.getArticleTaskRelationIds(start, limit);
	}

	@Override
	public Integer countArticleTaskRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.countArticleTaskRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getObjectByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return articleTaskRelationService.getObjectByDynamicCondition(aClass, map, integer, integer1);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return articleTaskRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   articleTaskRelationService.deleteList(clz, ids);
		
	}


 
}
